@@ -27,6 +27,7 @@
 #' components. \code{get_enrichment_options.lm()} returns the
 #' components and their descriptions.
 #'
+#' @method enrich lm
 #' @export
 `enrich.lm` <- function(object, with = "all", ...) {
     if (is.null(with)) {
@@ -106,6 +107,7 @@
 }
 
 
+#' @method compute_auxiliary_functions lm
 `compute_auxiliary_functions.lm` <- function(object, ...) {
     if (is.null(object$model)) {
         object <- update(object, model = TRUE)
@@ -158,7 +160,7 @@
     }
 
     information <- function(coefficients, dispersion,
-                            type = c("expected", "observed"), QR = FALSE) {
+                            type = c("expected", "observed"), QR = FALSE, CHOL = FALSE) {
         if (missing(coefficients)) {
             coefficients <- coef(object)
         }
@@ -188,6 +190,8 @@
         out <- rbind(cbind(info_beta, info_cross),
                      c(info_cross, info_dispe))
         colnames(out) <- rownames(out) <- c(colnames(x), "dispersion")
+        if (CHOL)
+            out <- chol(out)
         attr(out, "coefficients") <- coefficients
         attr(out, "dispersion") <- dispersion
         out
@@ -221,6 +225,11 @@
         if (missing(coefficients)) {
             coefficients <- coef(object)
         }
+        else {
+            if (!isTRUE(identical(length(coefficients), length(coef(object))))) {
+                stop("`coefficients` does not have the right length")
+            }
+        }
         if (missing(dispersion)) {
             dispersion <- enrich(object, with = "mle of dispersion")$dispersion_mle
         }
@@ -270,6 +279,7 @@
 }
 
 
+#' @method compute_score_mle lm
 `compute_score_mle.lm` <- function(object, ...) {
     get_score_function(object)()
 }
@@ -279,7 +289,7 @@
     UseMethod('compute_score_mle')
 }
 
-
+#' @method compute_dispersion_mle lm
 `compute_dispersion_mle.lm` <- function(object, ...) {
     prior_weights <- weights(object)
     nobs <- nobs(object)
@@ -296,32 +306,30 @@
     UseMethod('compute_dispersion_mle')
 }
 
-
-`compute_expected_information_mle.lm` <- function(object, dispersion) {
+#' @method compute_expected_information_mle lm
+`compute_expected_information_mle.lm` <- function(object, dispersion, ...) {
     get_information_function(object)(type = "expected")
 }
 
-
 `compute_expected_information_mle` <- function(object, ...) {
     UseMethod('compute_expected_information_mle')
 }
 
-
-`compute_observed_information_mle.lm` <- function(object, dispersion) {
+#' @method compute_observed_information_mle lm
+`compute_observed_information_mle.lm` <- function(object, dispersion, ...) {
     get_information_function(object)(type = "observed")
 }
 
-
 `compute_observed_information_mle` <- function(object, ...) {
     UseMethod('compute_observed_information_mle')
 }
 
 
+#' @method compute_bias_mle lm
 `compute_bias_mle.lm` <- function(object, ...) {
     get_bias_function(object)()
 }
 
-
 `compute_bias_mle` <- function(object, ...) {
     UseMethod('compute_bias_mle')
 }
@@ -461,9 +469,11 @@ get_score_function.lm <- function(object, ...) {
 #' matrix is evaluated. If missing then the maximum likelihood estimate
 #' is used}
 #'
-#' \item{type}{should the function return th 'expected' or 'observed' information? Default is \code{expected}}
+#' \item{type}{should the function return the 'expected' or 'observed' information? Default is \code{expected}}
 #'
-#' \item{QR}{If \code{TRUE}, then the QR decomposition of the expected information for the coefficients is returned}
+#' \item{QR}{If \code{TRUE}, then the QR decomposition of \deqn{W^{1/2} X} is returned, where \deqn{W} is a diagonal matrix with the working weights (\code{object$weights}) and \deqn{X} is the model matrix.}
+#'
+#' \item{CHOL}{If \code{TRUE}, then the Cholesky decomposition of the information matrix at the coefficients is returned}
 #'
 #' }
 #'
